#
# spec file for package ortp
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2014 Mariusz Fik <fisiu@opensuse.org>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname  libortp
%define sover   15

Name:           ortp
Version:        5.3.105
Release:        1.2
Summary:        Real-time Transport Protocol Stack
License:        AGPL-3.0-or-later
Group:          Productivity/Telephony/Utilities
URL:            https://linphone.org/technical-corner/ortp/
Source:         https://gitlab.linphone.org/BC/public/ortp/-/archive/%{version}/%{name}-%{version}.tar.bz2
Source99:       baselibs.conf
# PATCH-FIX-OPENSUSE deps.diff
Patch0:         deps.diff
Patch1:         set_current_version.patch
BuildRequires:  chrpath
BuildRequires:  cmake >= 3.22
BuildRequires:  gcc-c++
BuildRequires:  graphviz
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(bctoolbox) >= %{version}

%description
oRTP is a C library implementing the RTP protocol (RFC 1889).

%package -n %{soname}%{sover}
Summary:        Real-time Transport Protocol Stack
Group:          System/Libraries

%description -n %{soname}%{sover}
oRTP is a C library implementing the RTP protocol (RFC 1889).

%package devel
Summary:        Headers, libraries and docs for the oRTP library
Group:          Development/Libraries/C and C++
Requires:       %{soname}%{sover} = %{version}
Requires:       cmake
Provides:       %{soname}-devel = %{version}
Obsoletes:      %{soname}-devel < %{version}

%description devel
oRTP is a C library implementing the RTP protocol (RFC 1889).

This package contains header files and development libraries needed to
develop programs using the oRTP library.

%prep
%autosetup -p1

%build
%cmake \
  -DENABLE_STATIC=OFF \
  -DENABLE_DOC=OFF
%cmake_build

%install
%cmake_install

mkdir -p %{buildroot}%{_docdir}/%{name}
# manually keeping the version here because upstream doesn't (usually) update the patch version
mv -T %{buildroot}%{_datadir}/doc/%{name}-%{version} %{buildroot}%{_docdir}/%{name}

# for some reason, pkgconfig file contains wrong libdir
sed -i "s,-L/usr/lib,-L%{_libdir}," %{buildroot}/%{_libdir}/pkgconfig/%{name}.pc

chrpath -d %{buildroot}%{_libdir}/%{soname}.so.%{sover}* %{buildroot}%{_bindir}/ortp-tester

%post -n %{soname}%{sover} -p /sbin/ldconfig
%postun -n %{soname}%{sover} -p /sbin/ldconfig

%files
%doc %{_docdir}/%{name}/
%{_bindir}/ortp-tester

%files -n %{soname}%{sover}
%{_libdir}/%{soname}.so.%{sover}*

%files devel
%{_includedir}/%{name}/
%{_libdir}/%{soname}.so
%{_libdir}/pkgconfig/%{name}.pc
%dir %{_datadir}/Ortp
%dir %{_datadir}/Ortp/cmake
%{_datadir}/Ortp/cmake/*.cmake
%dir %{_datadir}/ortp-tester
%dir %{_datadir}/ortp-tester/raw
%{_datadir}/ortp-tester/raw/h265-iframe

%changelog
* Mon Feb 17 2025 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.3.105 (no changelog).
* Mon Nov 11 2024 ecsos <ecsos@opensuse.org>
- Update to 5.3.95 (no changelog).
* Sun Oct 13 2024 ecsos <ecsos@opensuse.org>
- Update to 5.3.89 (no changelog).
* Fri Mar 29 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.3.37 (no changelog).
* Thu Mar  7 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.3.26 (no changelog).
* Mon Jan 15 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.3.7 (no changelog).
* Sun Oct  8 2023 thod_@gmx.de
- Remove RPATH to be able to build on Fedora
* Mon Aug 28 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.2.98 (no changelog)
* Wed Jun 28 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.2.73 (no changelog)
* Fri Apr  7 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.2.49 (no changelog)
* Wed Mar  8 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.2.30 (no changelog)
- Add set_current_version.patch
* Sat Jan 28 2023 Dirk Müller <dmueller@suse.com>
- updaet to 5.2.16:
  * no changes
* Wed Jan 11 2023 Giacomo Comes <gcomes.obs@gmail.com> - 5.2.9
- Update to version 5.2.9:
  * no changes
- Update license tag to AGPL-3.0-or-later
* Wed Jan  4 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.2.6 (no changelog).
* Mon Oct 17 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.1.64 (no changelog).
* Fri Sep  9 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.1.58 (no changelog)
- Remove document generation until upstream fixes all issues
* Sun Aug 14 2022 thod_@gmx.de
- Remove RPATH to be able to build on Fedora
* Fri Jul  8 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to version 5.1.45:
  * Make DTLS-SRTP to start immediately after the default candidate pair is verified by ICE.
* Wed Jun  8 2022 Giacomo Comes <gcomes.obs@gmail.com> - 5.1.32
- Update to version 5.1.32:
  * fix leak of ortp_malloc in bundle mode
  * Add frame marking extension header
  * Factorize client and server pipe function to reuse bctbx code
  * Changed creation function with audio level to accept payload aswell
- revert license tag change
* Thu Mar 24 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to version 5.1.12:
  * no changelog
* Tue Mar  1 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to version 5.1.3:
  * New forward error correction (FEC) algorithm implemented
    according to https://datatracker.ietf.org/doc/html/rfc8627
  * Standalone compilation (out of linphone-sdk).
  * Bundle mode warnings and few inconsistencies.
* Tue Feb  1 2022 Giacomo Comes <gcomes.obs@gmail.com> - 5.0.67
- Update to version 5.0.67:
  * no changes
- fix license tag
* Tue Jan 18 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to version 5.0.66:
  * no changelog
* Sun Nov 21 2021 Giacomo Comes <gcomes.obs@gmail.com> - 5.0.53
- Update to version 5.0.53:
  * no changes
* Mon Nov  8 2021 Giacomo Comes <gcomes.obs@gmail.com> - 5.0.49
- Update to 5.0.49:
  * no changes
* Tue Nov  2 2021 Giacomo Comes <gcomes.obs@gmail.com> - 5.0.46
- Update to 5.0.46:
  * no changes
* Tue Oct 19 2021 Giacomo Comes <gcomes.obs@gmail.com> - 5.0.36
- Update to 5.0.36:
  * no changes
- Add BuildRequires:  graphviz
* Fri Oct 15 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.0.35:
  * no changelog
* Wed Jul 14 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.0.0:
  * small memory leak around TMMBR receiving.
* Tue Jun 22 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.5.20, no changelog
* Fri May 14 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.5.15 (no changelog)
* Sat May  8 2021 Dirk Müller <dmueller@suse.com>
- update to 4.5.13:
  * no change, just a rerelease
* Wed Apr 28 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.5.10 (no changelog)
* Thu Apr 15 2021 Luiz Angelo Daros de Luca <luizluca@tre-sc.jus.br>
- Update to 4.5.3
  * No changelog available.
* Wed Mar 31 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.5.0:
  * minor fixes
* Sun Mar  7 2021 Dirk Müller <dmueller@suse.com>
- update to 4.4.33:
  * RTP bundling according to https://tools.ietf.org/html/draft-ietf-mmusic-sdp-bundle-negotiation-54
  * RTP extension header support
  * IP_PKTINFO for outgoing packets - useful for ICE. This let specify the source IP address to use while sending a packet.
  * Random crash when network simulator is activated, while destroying an RtpSession.
  * Fix issue where DTLS handshake cannot take place when the media path goes through a TURN server
  * Fix a race condition around rtpsession's auxiliary destinations.
* Mon Feb 22 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.4.29 (no changelog)
* Fri Jan 22 2021 Jan Engelhardt <jengelh@inai.de>
- Trim redundancies from the description.
* Fri Jan 22 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.4.24 (no changelog)
* Thu Dec 31 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.4.21 (no changelog)
* Wed Dec  2 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.4.13 (no changelog)
* Thu Nov 12 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.4.7 (no changelog)
* Wed Nov  4 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.4.6 (no changelog)
* Fri Jun 26 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.4.0 (no changelog)
- Remove fix-cmakelists.patch
* Tue Mar  3 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.3.1 (no changelog)
- Add fix-cmakelists.patch file until upstream PR is merged
* Thu Jul 20 2017 sor.alexei@meowr.ru
- Update to version 1.0.2:
  * Bug fixes.
- Enable documentation installation.
* Wed Jul  5 2017 jengelh@inai.de
- Add deps.diff to fix the build of ortp users such as libosmo-abis.
* Sun Jun  4 2017 sor.alexei@meowr.ru
- Disable -Werror.
* Wed May 17 2017 sor.alexei@meowr.ru
- Update to version 1.0.1 (changes since 0.27.0):
  * oRTP licence is changed to be GPLv2+.
  * Add a new adaptive jitter buffer algorithm.
  * Minor enhancements and bugfixes.
* Tue Aug 16 2016 mpluskal@suse.com
- Update to version 0.27.0:
  * bctoolbox added as dependency
- Update download url (use github)
- Enable tests
- Switch to cmake build
* Sun Jan 24 2016 jengelh@inai.de
- Add tarball signature
* Fri Nov  6 2015 sor.alexei@meowr.ru
- Update to 0.25.0:
  * Support AVPF generic NACK.
  * Add payload types for RTT (Real-Time Text) and Codec2.
  * Bug fixes.
* Sat Aug 22 2015 tbechtold@suse.com
- update to 0.24.2:
  * Minor release v0.24.2
  * fix typo in rtcp_common_header_get padbit() macro definition
  * Add option to enable/disable documentation generation when building with CMake.
  * set correct dependency
  * configure.ac: add --disable-documentation option to speed up dev builds
  * re-add Requires field for devel rpm
  * AVPF TMMBR/TMMBN: set correct ssrc to handle TMMBR in one-way video calls
  * Release 0.24.1
  * devel package does not require explicit dependency
  * also add epoch to devel rpm
  * set rpm epoc to 1 to be alined with redhat rpm
  * logging.c: split line into 3
  * Fix redefinition of WINAPI_FAMILY_PARTITION when using MinGW64 (thanks to Henrik Pauli for pointing this).
  * increased the size of OrtpEventData.zrtp_sas.sas from 5 to 32 bytes to accomodate the B256 format SAS string
  * add rtp_session_get_symmetric_rtp
  * Define the "Additional #using Directories" when building winrttimer.cpp for Windows Phone.
  * improve logging
  * Fix last commit + allow use of C++.
  * Begin handling of build for Windows Phone with CMake.
  * Do not use absolute path in install instruction of CMake.
  * Fix crash with RTPFB and PSFB packets scheduling.
  * avoid uninstall to fail if nothing was installed before
  * Add support for TMMBR and TMMBN feedback messages (part of RFC 5104).
  * Fix possible receive bandwidth computation imprecision.
* Wed Jul 29 2015 dimstar@opensuse.org
- Add baselibs.conf: build libortp9-32bit, as needed by
  libmediastreamer_base4.
* Sun Mar 15 2015 sor.alexei@meowr.ru
- Update to 0.24.0:
  * RTCP send algorithm as describe in RFC3550.
  * RTCP XR (RFC3611).
  * RTCP send algorithm as describe in RFC4585: AVPF streams.
* Sun May 25 2014 fisiu@opensuse.org
- Update to 0.23.0:
  * network simulator improvements
  * updated to use ZRTPCPP>=4.0
  * security bugfixes
* Wed Jun 26 2013 fisiu@opensuse.org
- ortp-devel obsoletes libortp-devel now.
* Fri Jun 21 2013 fisiu@opensuse.org
- Update to 0.22.0:
  * network simulator improvements for simulating random lost packets
  * srtp initialization bugfix
- Source package renamed to ortp.
* Wed Oct 10 2012 mailaender@opensuse.org
- update to 0.20.0
  - fix an issue on video call with ZRTP
  - ZRTP media encryption
  - SRTP media encryption
  - RTCP support fixes
  - add rtp_session_get_round_trip_propagation()
  - optimisations in session-set intersection computation
  - workaround fix for some versions of uclibc
* Tue Jan 31 2012 jengelh@medozas.de
- Remove redundant tags/sections per specfile guideline suggestions
* Sun Nov  7 2010 pascal.bleser@opensuse.org
- fix Group tags
* Sun Jul 18 2010 dmacvicar@suse.de
- create ortp8 package (0.16.3) from ortp5 (0.13.1)
* Fri Dec 21 2007 crrodriguez@suse.de
- initial package version, required for linphone
